@@ -1,10 +1,31 @@
-# $Id: Names.pm,v 1.3 2005/09/13 18:50:49 peterhickman Exp $
-
 package Data::RandomPerson::Names;
 
 use strict;
 use warnings;
 
+use Data::RandomPerson::Choice;
+use File::Share ':all';
+
+sub new {
+    my ($class) = @_;
+
+    my $self = bless {}, $class;
+
+    $self->{choice} = Data::RandomPerson::Choice->new();
+
+    my $module = (split /::/, $class)[-1];
+
+    my $file = dist_file ('Data-RandomPerson', $module . '.txt');
+    open ( my $fh, '< :encoding(UTF8)', $file) or die "Can't open '$file': $!";
+    my @file = <$fh>;
+    close $fh;
+
+    chomp (@file);
+    $self->{choice}->add_list(@file);
+
+    return $self;
+}
+
 sub size {
     my ($self) = @_;
 
@@ -25,10 +46,6 @@ __END__
 
 Data::RandomPerson::Names - Base class to hold the common methods required for the names
 
-=head1 VERSION
-
-This document refers to version 0.4 of Data::RandomPerson::Names, released Sept 13th, 2005
-
 =head1 SYNOPSIS
 
 There is no need to call this class
@@ -63,32 +80,12 @@ Returns an element from the list.
 
 =back
 
-=head1 ENVIRONMENT
-
-Perl 5
-
-=head1 DIAGNOSTICS
-
-None from this code
-
-=head1 BUGS
-
-None so far
-
-=head1 FILES
-
-None
-
-=head1 SEE ALSO
-
-None
-
 =head1 AUTHOR
 
 Peter Hickman (peterhi@ntlworld.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005, Peter Hickman. All rights reserved. This module is
+Copyright (c) 2005, Peter Hickman. This module is
 free software. It may be used, redistributed and/or modified under the
 same terms as Perl itself.
